==> primevue-3.46.0.tgz: package/icons/ban/index.js <==
this.primevue = this.primevue || {};
this.primevue.icons = this.primevue.icons || {};
this.primevue.icons.ban = (function (BaseIcon, utils, vue) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var BaseIcon__default = /*#__PURE__*/_interopDefaultLegacy(BaseIcon);

    var script = {
      name: 'BanIcon',
      "extends": BaseIcon__default["default"],
      computed: {
        pathId: function pathId() {
          return "pv_icon_clip_".concat(utils.UniqueComponentId());
        }
      }
    };

    var _hoisted_1 = ["clip-path"];
    var _hoisted_2 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M7 0C5.61553 0 4.26215 0.410543 3.11101 1.17971C1.95987 1.94888 1.06266 3.04213 0.532846 4.32122C0.00303296 5.6003 -0.13559 7.00776 0.134506 8.36563C0.404603 9.7235 1.07129 10.9708 2.05026 11.9497C3.02922 12.9287 4.2765 13.5954 5.63437 13.8655C6.99224 14.1356 8.3997 13.997 9.67879 13.4672C10.9579 12.9373 12.0511 12.0401 12.8203 10.889C13.5895 9.73785 14 8.38447 14 7C14 5.14348 13.2625 3.36301 11.9497 2.05025C10.637 0.737498 8.85652 0 7 0ZM1.16667 7C1.16549 5.65478 1.63303 4.35118 2.48889 3.31333L10.6867 11.5111C9.83309 12.2112 8.79816 12.6544 7.70243 12.789C6.60669 12.9236 5.49527 12.744 4.49764 12.2713C3.50001 11.7986 2.65724 11.0521 2.06751 10.1188C1.47778 9.18558 1.16537 8.10397 1.16667 7ZM11.5111 10.6867L3.31334 2.48889C4.43144 1.57388 5.84966 1.10701 7.29265 1.1789C8.73565 1.2508 10.1004 1.85633 11.1221 2.87795C12.1437 3.89956 12.7492 5.26435 12.8211 6.70735C12.893 8.15034 12.4261 9.56856 11.5111 10.6867Z",
      fill: "currentColor"
    }, null, -1);
    var _hoisted_3 = [_hoisted_2];
    var _hoisted_4 = ["id"];
    var _hoisted_5 = /*#__PURE__*/vue.createElementVNode("rect", {
      width: "14",
      height: "14",
      fill: "white"
    }, null, -1);
    var _hoisted_6 = [_hoisted_5];
    function render(_ctx, _cache, $props, $setup, $data, $options) {
      return vue.openBlock(), vue.createElementBlock("svg", vue.mergeProps({
        width: "14",
        height: "14",
        viewBox: "0 0 14 14",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, _ctx.pti()), [vue.createElementVNode("g", {
        "clip-path": "url(#".concat($options.pathId, ")")
      }, _hoisted_3, 8, _hoisted_1), vue.createElementVNode("defs", null, [vue.createElementVNode("clipPath", {
        id: "".concat($options.pathId)
      }, _hoisted_6, 8, _hoisted_4)])], 16);
    }

    script.render = render;

    return script;

})(primevue.baseicon, primevue.utils, Vue);

==> primevue-3.47.0.tgz: package/icons/ban/index.js <==
this.primevue = this.primevue || {};
this.primevue.icons = this.primevue.icons || {};
this.primevue.icons.ban = (function (BaseIcon, vue) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var BaseIcon__default = /*#__PURE__*/_interopDefaultLegacy(BaseIcon);

    var script = {
      name: 'BanIcon',
      "extends": BaseIcon__default["default"]
    };

    var _hoisted_1 = ["clip-path"];
    var _hoisted_2 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M7 0C5.61553 0 4.26215 0.410543 3.11101 1.17971C1.95987 1.94888 1.06266 3.04213 0.532846 4.32122C0.00303296 5.6003 -0.13559 7.00776 0.134506 8.36563C0.404603 9.7235 1.07129 10.9708 2.05026 11.9497C3.02922 12.9287 4.2765 13.5954 5.63437 13.8655C6.99224 14.1356 8.3997 13.997 9.67879 13.4672C10.9579 12.9373 12.0511 12.0401 12.8203 10.889C13.5895 9.73785 14 8.38447 14 7C14 5.14348 13.2625 3.36301 11.9497 2.05025C10.637 0.737498 8.85652 0 7 0ZM1.16667 7C1.16549 5.65478 1.63303 4.35118 2.48889 3.31333L10.6867 11.5111C9.83309 12.2112 8.79816 12.6544 7.70243 12.789C6.60669 12.9236 5.49527 12.744 4.49764 12.2713C3.50001 11.7986 2.65724 11.0521 2.06751 10.1188C1.47778 9.18558 1.16537 8.10397 1.16667 7ZM11.5111 10.6867L3.31334 2.48889C4.43144 1.57388 5.84966 1.10701 7.29265 1.1789C8.73565 1.2508 10.1004 1.85633 11.1221 2.87795C12.1437 3.89956 12.7492 5.26435 12.8211 6.70735C12.893 8.15034 12.4261 9.56856 11.5111 10.6867Z",
      fill: "currentColor"
    }, null, -1);
    var _hoisted_3 = [_hoisted_2];
    var _hoisted_4 = ["id"];
    var _hoisted_5 = /*#__PURE__*/vue.createElementVNode("rect", {
      width: "14",
      height: "14",
      fill: "white"
    }, null, -1);
    var _hoisted_6 = [_hoisted_5];
    function render(_ctx, _cache, $props, $setup, $data, $options) {
      return vue.openBlock(), vue.createElementBlock("svg", vue.mergeProps({
        width: "14",
        height: "14",
        viewBox: "0 0 14 14",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, _ctx.pti()), [vue.createElementVNode("g", {
        "clip-path": "url(#".concat(_ctx.pathId, ")")
      }, _hoisted_3, 8, _hoisted_1), vue.createElementVNode("defs", null, [vue.createElementVNode("clipPath", {
        id: "".concat(_ctx.pathId)
      }, _hoisted_6, 8, _hoisted_4)])], 16);
    }

    script.render = render;

    return script;

})(primevue.baseicon, Vue);
